@@ -1,3 +1,5 @@
+# Original comment:
+#
 # Adds a newline after print. Some readlines need it some don't. I guess
 # we should clarify whether this is a bug and if so whose bug at some point
 # but this'll do for now ;)
@@ -7,12 +9,12 @@ package Devel::REPL::Plugin::NewlineHack;
 use Moose::Role;
 use namespace::clean -except => [ 'meta' ];
 
-after 'print' => sub {
-  # not fussed about args
-  my ($self) = @_;
-  my $fh = $self->out_fh;
-  print $fh "\n";
-};
+warn <<EOW;
+No longer required, extra newline automatically produced for Gnu readline
+implementation by Devel::REPL's print() method.
+
+This plugin will be removed at some point; please remove it from your config.
+EOW
 
 1;
 
